@@ -1,14 +1,5 @@
 arch_get_kernel_flavour () {
-	VENDOR=`grep '^vendor_id' "$CPUINFO" | head -n1 | cut -d: -f2`
-	case "$VENDOR" in
-	    " AuthenticAMD"*)
-		echo amd64-k8 ;;
-	    " GenuineIntel"*)
-		echo em64t-p4 ;;
-	    *)
-		echo amd64-generic ;;
-	esac
-	return 0
+	echo amd64
 }
 
 arch_check_usable_kernel () {
