@@ -769,7 +769,7 @@ class Install(install_misc.InstallBase):
                         continue
                     if not os.path.exists(words[0]):
                         continue
-                    if words[0].startswith('/dev/ramzswap'):
+                    if words[0].startswith('/dev/zram'):
                         continue
                     size = int(words[2])
                     if size > biggest_size:
@@ -1225,6 +1225,16 @@ class Install(install_misc.InstallBase):
                                 'metadata::trusted', 'true')
                             break
 
+                    # Disable gnome-initial-setup for the OEM user
+                    install_misc.chrex(
+                        self.target, 'install', '-d',
+                        '-o', 'oem', '-g', 'oem',
+                        '/home/oem/.config')
+                    install_misc.chrex(
+                        self.target,
+                        'sudo', '-i', '-u', 'oem',
+                        'touch', '/home/oem/.config/gnome-initial-setup-done')
+
                 # Carry the locale setting over to the installed system.
                 # This mimics the behavior in 01oem-config-udeb.
                 di_locale = self.db.get('debian-installer/locale')
@@ -1396,6 +1406,14 @@ class Install(install_misc.InstallBase):
         else:
             difference = set()
 
+        # Add minimal installation package list if selected
+        if self.db.get('ubiquity/minimal_install') == 'true':
+            if os.path.exists(install_misc.minimal_install_rlist_path):
+                rm = set()
+                with open(install_misc.minimal_install_rlist_path) as m_file:
+                    rm = {line.strip().split(':')[0] for line in m_file}
+                difference |= rm
+
         # Keep packages we explicitly installed.
         keep = install_misc.query_recorded_installed()
 
