@@ -32,7 +32,7 @@ import sys
 
 from gi.repository import GLib
 
-from ubiquity import filteredcommand, i18n, misc
+from ubiquity import filteredcommand, i18n, misc, telemetry
 from ubiquity.components import install, plugininstall, partman_commit
 import ubiquity.frontend.base
 from ubiquity.frontend.base import BaseFrontend
@@ -77,6 +77,9 @@ class Wizard(BaseFrontend):
                   file=self.console)
             sys.exit(1)
 
+        telemetry.get().set_installer_type('NonInteractive')
+        telemetry.get().add_stage(telemetry.START_INSTALL_STAGE_TAG)
+
         for x in self.pages:
             if issubclass(x.filter_class, Plugin):
                 ui = x.ui
@@ -110,6 +113,7 @@ class Wizard(BaseFrontend):
         if ret == 0:
             self.run_success_cmd()
             print('Installation complete.', file=self.console)
+            telemetry.get().done(self.db)
             if self.get_reboot():
                 misc.execute("reboot")
         if ret != 0:
@@ -124,7 +128,7 @@ class Wizard(BaseFrontend):
                 with open('/var/lib/ubiquity/install.trace') as tbfile:
                     realtb = tbfile.read()
                 raise RuntimeError("Install failed with exit code %s\n%s" %
-                                  (ret, realtb))
+                                   (ret, realtb))
 
     def watch_debconf_fd(self, from_debconf, process_input):
         """Event loop interface to debconffilter.
